/****************************************************************************
** Meta object code from reading C++ file 'ksanewidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksane-26.07.90/src/ksanewidget.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksanewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KSaneIface11KSaneWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KSaneIface::KSaneWidget::qt_create_metaobjectdata<qt_meta_tag_ZN10KSaneIface11KSaneWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSaneIface::KSaneWidget",
        "scannedImageReady",
        "",
        "QImage",
        "scannedImage",
        "scanDone",
        "status",
        "strStatus",
        "userMessage",
        "type",
        "scanProgress",
        "percent",
        "availableDevices",
        "QList<KSaneIface::KSaneWidget::DeviceInfo>",
        "deviceList",
        "buttonPressed",
        "optionName",
        "optionLabel",
        "pressed",
        "openedDeviceInfoUpdated",
        "deviceName",
        "deivceVendor",
        "deviceModel",
        "cancelScan",
        "startScan",
        "startPreviewScan"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'scannedImageReady'
        QtMocHelpers::SignalData<void(const QImage &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'scanDone'
        QtMocHelpers::SignalData<void(int, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'userMessage'
        QtMocHelpers::SignalData<void(int, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'scanProgress'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'availableDevices'
        QtMocHelpers::SignalData<void(const QList<KSaneIface::KSaneWidget::DeviceInfo> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'buttonPressed'
        QtMocHelpers::SignalData<void(const QString &, const QString &, bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Signal 'openedDeviceInfoUpdated'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'cancelScan'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startScan'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startPreviewScan'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KSaneWidget, qt_meta_tag_ZN10KSaneIface11KSaneWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSaneIface::KSaneWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSaneIface11KSaneWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSaneIface11KSaneWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KSaneIface11KSaneWidgetE_t>.metaTypes,
    nullptr
} };

void KSaneIface::KSaneWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KSaneWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->scannedImageReady((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 1: _t->scanDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->userMessage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->scanProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->availableDevices((*reinterpret_cast<std::add_pointer_t<QList<KSaneIface::KSaneWidget::DeviceInfo>>>(_a[1]))); break;
        case 5: _t->buttonPressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 6: _t->openedDeviceInfoUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->cancelScan(); break;
        case 8: _t->startScan(); break;
        case 9: _t->startPreviewScan(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KSaneWidget::*)(const QImage & )>(_a, &KSaneWidget::scannedImageReady, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSaneWidget::*)(int , const QString & )>(_a, &KSaneWidget::scanDone, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSaneWidget::*)(int , const QString & )>(_a, &KSaneWidget::userMessage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSaneWidget::*)(int )>(_a, &KSaneWidget::scanProgress, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSaneWidget::*)(const QList<KSaneIface::KSaneWidget::DeviceInfo> & )>(_a, &KSaneWidget::availableDevices, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSaneWidget::*)(const QString & , const QString & , bool )>(_a, &KSaneWidget::buttonPressed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSaneWidget::*)(const QString & , const QString & , const QString & )>(_a, &KSaneWidget::openedDeviceInfoUpdated, 6))
            return;
    }
}

const QMetaObject *KSaneIface::KSaneWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSaneIface::KSaneWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSaneIface11KSaneWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KSaneIface::KSaneWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KSaneIface::KSaneWidget::scannedImageReady(const QImage & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KSaneIface::KSaneWidget::scanDone(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KSaneIface::KSaneWidget::userMessage(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KSaneIface::KSaneWidget::scanProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KSaneIface::KSaneWidget::availableDevices(const QList<KSaneIface::KSaneWidget::DeviceInfo> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KSaneIface::KSaneWidget::buttonPressed(const QString & _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void KSaneIface::KSaneWidget::openedDeviceInfoUpdated(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
