/****************************************************************************
** Meta object code from reading C++ file 'ksaneviewer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksane-26.07.90/src/ksaneviewer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksaneviewer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KSaneIface11KSaneViewerE_t {};
} // unnamed namespace

template <> constexpr inline auto KSaneIface::KSaneViewer::qt_create_metaobjectdata<qt_meta_tag_ZN10KSaneIface11KSaneViewerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSaneIface::KSaneViewer",
        "newSelection",
        "",
        "tl_x",
        "tl_y",
        "br_x",
        "br_y",
        "setTLX",
        "ratio",
        "setTLY",
        "setBRX",
        "setBRY",
        "setSelection",
        "clearActiveSelection",
        "clearSavedSelections",
        "clearSelections",
        "setHighlightArea",
        "setHighlightShown",
        "percentage",
        "QColor",
        "hideColor",
        "clearHighlight",
        "zoomIn",
        "zoomOut",
        "zoomSel",
        "zoom2Fit",
        "selListSize",
        "selectionAt",
        "index",
        "float&",
        "setMultiselectionEnabled",
        "enabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newSelection'
        QtMocHelpers::SignalData<void(float, float, float, float)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 3 }, { QMetaType::Float, 4 }, { QMetaType::Float, 5 }, { QMetaType::Float, 6 },
        }}),
        // Slot 'setTLX'
        QtMocHelpers::SlotData<void(float)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 8 },
        }}),
        // Slot 'setTLY'
        QtMocHelpers::SlotData<void(float)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 8 },
        }}),
        // Slot 'setBRX'
        QtMocHelpers::SlotData<void(float)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 8 },
        }}),
        // Slot 'setBRY'
        QtMocHelpers::SlotData<void(float)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 8 },
        }}),
        // Slot 'setSelection'
        QtMocHelpers::SlotData<void(float, float, float, float)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 3 }, { QMetaType::Float, 4 }, { QMetaType::Float, 5 }, { QMetaType::Float, 6 },
        }}),
        // Slot 'clearActiveSelection'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSavedSelections'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSelections'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setHighlightArea'
        QtMocHelpers::SlotData<void(float, float, float, float)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 3 }, { QMetaType::Float, 4 }, { QMetaType::Float, 5 }, { QMetaType::Float, 6 },
        }}),
        // Slot 'setHighlightShown'
        QtMocHelpers::SlotData<void(int, QColor)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setHighlightShown'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'clearHighlight'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomSel'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoom2Fit'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selListSize'
        QtMocHelpers::SlotData<int()>(26, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'selectionAt'
        QtMocHelpers::SlotData<bool(int, float &, float &, float &, float &)>(27, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 28 }, { 0x80000000 | 29, 3 }, { 0x80000000 | 29, 4 }, { 0x80000000 | 29, 5 },
            { 0x80000000 | 29, 6 },
        }}),
        // Slot 'setMultiselectionEnabled'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KSaneViewer, qt_meta_tag_ZN10KSaneIface11KSaneViewerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSaneIface::KSaneViewer::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSaneIface11KSaneViewerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSaneIface11KSaneViewerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KSaneIface11KSaneViewerE_t>.metaTypes,
    nullptr
} };

void KSaneIface::KSaneViewer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KSaneViewer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newSelection((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[4]))); break;
        case 1: _t->setTLX((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 2: _t->setTLY((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 3: _t->setBRX((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 4: _t->setBRY((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 5: _t->setSelection((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[4]))); break;
        case 6: _t->clearActiveSelection(); break;
        case 7: _t->clearSavedSelections(); break;
        case 8: _t->clearSelections(); break;
        case 9: _t->setHighlightArea((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[4]))); break;
        case 10: _t->setHighlightShown((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        case 11: _t->setHighlightShown((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->clearHighlight(); break;
        case 13: _t->zoomIn(); break;
        case 14: _t->zoomOut(); break;
        case 15: _t->zoomSel(); break;
        case 16: _t->zoom2Fit(); break;
        case 17: { int _r = _t->selListSize();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->selectionAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<float&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<float&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<float&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setMultiselectionEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KSaneViewer::*)(float , float , float , float )>(_a, &KSaneViewer::newSelection, 0))
            return;
    }
}

const QMetaObject *KSaneIface::KSaneViewer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSaneIface::KSaneViewer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KSaneIface11KSaneViewerE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int KSaneIface::KSaneViewer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void KSaneIface::KSaneViewer::newSelection(float _t1, float _t2, float _t3, float _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}
QT_WARNING_POP
